@@ -39,7 +39,7 @@ typedef struct _GKMAttributeDisplayPrivate  GKMAttributeDisplayPrivate;
 
 struct _GKMAttributeDisplay
 {
-  GtkBin parent;
+  GtkVBox parent;
 
   GKMAttributeDisplayPrivate *priv;
 };
@@ -47,6 +47,12 @@ struct _GKMAttributeDisplay
 struct _GKMAttributeDisplayClass
 {
   GtkVBoxClass parent;
+
+  void (* secret_changed)    (GKMAttributeDisplay *display,
+			      gchar               *new_secret);
+
+  void (* attribute_changed) (GKMAttributeDisplay *display,
+			      gpointer             new_attributes);
 };
 
 GType gkm_attribute_display_get_type (void);
