@@ -103,15 +103,15 @@ complain_about_gnome_keyring_bad_result (GtkWindow          *transient_parent,
   switch (result) 
     {
       case GNOME_KEYRING_RESULT_NO_KEYRING_DAEMON:
-        error_dialog (GTK_WINDOW (transient_parent), _("GNOME Keyring daemon is not running."));
+        error_dialog (GTK_WINDOW (transient_parent), _("Keyring daemon is not running."));
         break;
         
       case GNOME_KEYRING_RESULT_IO_ERROR:
-        error_dialog (GTK_WINDOW (transient_parent), _("Cannot communicate with GNOME Keyring daemon."));
+        error_dialog (GTK_WINDOW (transient_parent), _("Cannot communicate with the keyring daemon."));
         break;
         
       case GNOME_KEYRING_RESULT_DENIED:
-        error_dialog (GTK_WINDOW (transient_parent), _("Access denied to GNOME Keyring."));
+        error_dialog (GTK_WINDOW (transient_parent), _("Access denied to the keyring."));
         break;
 
       case GNOME_KEYRING_RESULT_ALREADY_EXISTS:
@@ -131,7 +131,7 @@ complain_about_gnome_keyring_bad_result (GtkWindow          *transient_parent,
         break;
 
       default:
-        error_dialog (GTK_WINDOW (transient_parent), _("Unknown GNOME Keyring error."));
+        error_dialog (GTK_WINDOW (transient_parent), _("Unknown keyring error."));
     }
 }
 
@@ -324,14 +324,14 @@ gkm_show_about_dialog (GtkWindow *transient_parent)
   gtk_show_about_dialog (transient_parent,
 			 "name", _("Keyring Manager"),
 			 "version", VERSION,
-			 "comments",_("A simple keyring manager for GNOME 2"),
+			 "comments",_("A tool to manage the information stored in your keyrings."),
 			 "authors", authors,
 			 "copyright", _("Copyright \302\251 2004, 2005 The GNOME Love Project"),
 			 "documenters", NULL /* FIXME! */,
 			 "license", GPL,
 			 "logo-icon-name", "stock_keyring",
 			 "translator-credits", _("translator-credits"),
-			 "website", "http://www.gnome.org",
+			 "website", "http://www.gnome.org/",
 			 /* FIXME: add a "website-label" */
 			 NULL);
 }
@@ -378,7 +378,7 @@ toggle_view_column_action (GtkToggleAction *toggle_action,
   old_state = gconf_client_get_bool (gconf_client, key, &error);
   if (error != NULL)
     {
-      g_warning (_("Error while trying to read the gconf key %s: %s"), key, error->message);
+      g_warning ("Error while trying to read the gconf key %s: %s", key, error->message);
       g_error_free (error);
     }
  
@@ -395,7 +395,7 @@ toggle_view_column_action (GtkToggleAction *toggle_action,
   gconf_client_set_bool (gconf_client, key, state, &error);
   if (error != NULL)
     {
-      g_warning (_("Error while setting the gconf key %s: %s"), key, error->message);
+      g_warning ("Error while setting the gconf key %s: %s", key, error->message);
       g_error_free (error);
     }
 }
@@ -441,7 +441,7 @@ set_column_visibility_preferences (const SetColumnPrefsData *toggle,
   gconf_client_add_dir (gconf_client, dir, GCONF_CLIENT_PRELOAD_ONELEVEL, &error); 
   if (error != NULL)
     {
-      g_warning (_("Error trying to add %s to the list of gconf directories we listen to: %s"), dir, error->message);
+      g_warning ("Error trying to add %s to the list of gconf directories we listen to: %s", dir, error->message);
       g_error_free (error);
     }
 
@@ -465,7 +465,7 @@ set_column_visibility_preferences (const SetColumnPrefsData *toggle,
       state = gconf_client_get_bool (gconf_client, key, &error); 
       if (error != NULL)
         {
-          g_warning (_("Error while trying to read the gconf key %s: %s"), key, error->message);
+          g_warning ("Error while trying to read the gconf key %s: %s", key, error->message);
           g_error_free (error);
         }
 
@@ -476,7 +476,7 @@ set_column_visibility_preferences (const SetColumnPrefsData *toggle,
       id = gconf_client_notify_add (gconf_client, key, (GConfClientNotifyFunc) update_column_visibility, column, NULL, &error);
       if (error != NULL)
         {
-          g_warning (_("Error while trying to add a listener for changes on the gconf key %s: %s"), key, error->message);
+          g_warning ("Error while trying to add a listener for changes on the gconf key %s: %s", key, error->message);
           g_error_free (error);
         }
 
